@@ -1,10 +1,10 @@
 /*
- * Logswan 2.1.2
- * Copyright (c) 2015-2019, Frederic Cambus
+ * Logswan 2.1.3
+ * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2019-10-28
+ * Last Updated: 2020-01-17
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
@@ -83,7 +83,8 @@ char *intputFile;
 char *db = NULL;
 
 void
-displayUsage() {
+displayUsage()
+{
 	printf("USAGE: logswan [options] inputfile\n\n" \
 	    "Options are:\n\n" \
 	    "	-d Specify path to a GeoIP database\n" \
@@ -93,7 +94,8 @@ displayUsage() {
 }
 
 int
-main(int argc, char *argv[]) {
+main(int argc, char *argv[])
+{
 	int gai_error, mmdb_error;
 	MMDB_lookup_result_s lookup;
 
@@ -158,7 +160,6 @@ main(int argc, char *argv[]) {
 			perror("Can't open database");
 			return EXIT_FAILURE;
 		}
-
 	}
 
 	/* Open log file */
@@ -325,8 +326,8 @@ main(int argc, char *argv[]) {
 	strftime(results.timeStamp, 20, "%Y-%m-%d %H:%M:%S", localtime(&now));
 
 	/* Printing results */
-	fprintf(stderr, "Processed %" PRIu64 " lines in %f seconds.\n", results.processedLines, results.runtime);
 	fprintf(stdout, "%s\n", output(&results));
+	fprintf(stderr, "Processed %" PRIu64 " lines in %f seconds.\n", results.processedLines, results.runtime);
 
 	/* Clean up */
 	fclose(logFile);
