@@ -1,6 +1,6 @@
 /*
- * Logswan 2.1.2
- * Copyright (c) 2015-2019, Frederic Cambus
+ * Logswan 2.1.3
+ * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
@@ -20,7 +20,8 @@
 #include "output.h"
 
 char
-*output(struct results *results) {
+*output(struct results *results)
+{
 	json_t *output = json_object();
 	json_t *hits = json_object();
 	json_t *visits = json_object();
