@@ -1,6 +1,6 @@
 /*
- * Logswan 2.1.2
- * Copyright (c) 2015-2019, Frederic Cambus
+ * Logswan 2.1.3
+ * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
@@ -15,7 +15,8 @@
 #include "parse.h"
 
 void
-parseDate(struct date *parsedDate, char *date) {
+parseDate(struct date *parsedDate, char *date)
+{
 	parsedDate->day = strtok(date, "/");
 	parsedDate->month = strtok(NULL, "/");
 	parsedDate->year = strtok(NULL, ":");
@@ -25,7 +26,8 @@ parseDate(struct date *parsedDate, char *date) {
 }
 
 void
-parseLine(struct logLine *parsedLine, char *lineBuffer) {
+parseLine(struct logLine *parsedLine, char *lineBuffer)
+{
 	if (*lineBuffer) {
 		/* Remote host */
 		parsedLine->remoteHost = strtok(lineBuffer, " ");
@@ -52,7 +54,8 @@ parseLine(struct logLine *parsedLine, char *lineBuffer) {
 }
 
 void
-parseRequest(struct request *parsedRequest, char *request) {
+parseRequest(struct request *parsedRequest, char *request)
+{
 	char *pch = strrchr(request, ' ');
 
 	if (pch) {
